Module: Kernel
- Defined in:
- lib/cryolite.rb
Overview
This icky blob of code aliases the Ruby's "respond_to?" method to "responds_to?", making it easier to maintain the source level compatibility with Crystal. And also provides access to the "eval_if_run_by_ruby" function, which does "eval" when the code is run by Ruby, but does nothing when the code is compiled by Crystal. It can be used to define additional aliases necessary for Ruby/Crystal compatibility.
Instance Method Summary collapse
Dynamic Method Handling
This class handles dynamic methods through the method_missing method
#method_missing(name, *args) ⇒ Object
29 |
# File 'lib/cryolite.rb', line 29 def method_missing(name, *args) true end |